/* Terraform - (C) 1997-2000 Robert Gasch (r.gasch@chello.nl)
 *  - http://212.187.12.197/RNG/terraform/
 *  - http://terraform.sourceforge.net
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef _TF_WINDOW_H
#define _TF_WINDOW_H 1

#include <gtk--/box.h>
#include <gtk--/menu.h>
#include <gtk--/menubar.h>
#include <gtk--/menushell.h>
#include <gtk--/window.h>

#include "GuiBufferedDrawingArea.h"
#include "GuiColormap.h"
#include "GuiColormapLinear.h"
#include "GuiColormapBands.h"
#include "glib--hash.h"


/**
 *  TFWindow: the main (drawing) window for terraform. The Window includes: 
 * 	GuiBufferedDrawingArea (via inheritance)
 * 	Menu + Accelerators
 * 	either MenuBar or Popup Menu 
 */
class TFWindow : public Gtk::Window
	{
	public: 
				TFWindow (); 
		virtual		~TFWindow (); 
		virtual void 	quit ();
		virtual void	fileMenuCallback (string m);
		virtual void	editMenuCallback (string m);
		virtual void	hfMenuCallback (string m);
		virtual void	viewMenuCallback (string m);
		virtual void	colormapMenuCallback (string m);
		void		setSize (int x, int y);
		static char 	*buildAccel (const char *menu, char accelType, char *s);
		const GuiBufferedDrawingArea *getDrawingArea () {return p_da;}

	protected: 
		//void		hide_impl ();
		//void		show_impl ();
		void		addMenus ();
		void		allocColormaps ();
		void		buildWindowFixedMenu ();
		void		buildWindowFloatingMenu ();

		static GuiColormapLinear *s_linearColorMap,
					*s_linearColorMap2;
		static GuiColormapBands	*s_bandColorMap,
					*s_bandColorMap2;

		bool			d_useLinearColormap;
		int			d_nameCount;

		Gtk::VBox 		d_vbox;
		Gtk::MenuBar		*p_menuBar;
		Gtk::Menu 		*p_popupMenu;
		GuiBufferedDrawingArea	*p_da;
		char			**p_mNames;

		// menu elems who's sensitivity can change 
		Gtk::MenuItem		*p_miReload, *p_miMerge, 
					*p_miUndo;
		Gtk::CheckMenuItem	*p_cmiAutoRotate;
	};


#endif // _TF_WINDOW_H

